module.exports = defineTest({
	description: 'renders tree-shaken variable declarations'
});
